# Table of Contents

- [fact-sheet-shape-templates](<./fact-sheet-shape-templates.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Fact Sheet Shape Templates](<./Fact-Sheet-Shape-Templates.md>)
  - [Overview](<./Fact-Sheet-Shape-Templates/Overview.md>)
  - [Template Permissions](<./Fact-Sheet-Shape-Templates/Template-Permissions.md>)
  - [Creating Custom Shape Templates](<./Fact-Sheet-Shape-Templates/Creating-Custom-Shape-Templates.md>)
  - [Setting a Template as Default](<./Fact-Sheet-Shape-Templates/Setting-a-Template-as-Default.md>)
  - [Editing Existing Templates](<./Fact-Sheet-Shape-Templates/Editing-Existing-Templates.md>)
  - [Adding Complex Custom Shapes to the Fact Sheet Shape Templates](<./Fact-Sheet-Shape-Templates/Adding-Complex-Custom-Shapes-to-the-Fact-Sheet-Shape-Templates.md>)
  - [Selecting Fact Sheet Shape Templates](<./Fact-Sheet-Shape-Templates/Selecting-Fact-Sheet-Shape-Templates.md>)
  - [Using Shape Variants](<./Fact-Sheet-Shape-Templates/Using-Shape-Variants.md>)
  - [Using Shapes from Other Templates](<./Fact-Sheet-Shape-Templates/Using-Shapes-from-Other-Templates.md>)
